degree

# XMLRésuméLibrary: User Guide

dayOfMonth | Element Reference | degrees

## Name

degree — Container for information about a degree or similar certification

## Synopsis

### Content Model

    (level,annotation?,major*,minor*,(date|period)?,(institution,location?)?,gpa?,subjects?,projects?)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `degree` element is a container for information about an academic degree (Bachelor of Science, Doctor of Psychology, etc.) or other similar certification.

### Parents

`degree` may be contained in these elements: `degrees`

### Attributes

`id`

  A string used to uniquely identify a degree. The degree may then be referred to by this identifier.

## Examples

    <degree>
      <level>Ph.D</level>
      <major>Microbiology</major>
      <annotation>Thesis on effect of hot dogs on canine amino acids</annotation>
    </degree>

    <degree>
      <level>BA</level>
      <major>Toilet Paper Pattern Design</major>
      <date>
        <month>June</month>
        <year>1745</year>
      </date>
      <institution>British Design Academy</institution>
      <annotation>
        On dean's list for duration of studies.
      </annotation>
    </degree>

    <degree>
      <level>BS</level>
      <major>Computer Science</major>
      <major>English</major>
      <minor>Graphic Design</minor>
      <minor>Geography</minor>
      <subjects>
        <subject>
          <title>Compilers</title>
          <result>A-</result>
        </subject>
        <subject>
          <title>Data Structures</title>
          <result>B</result>
        </subject>
        <subject>
          <title>Classic Literature</title>
          <result>A</result>
        </subject>
      </subjects>
    </degree>

dayOfMonth | Element Reference | degrees